@@ -34,7 +34,7 @@ HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTIO
 CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE
 OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
  
- $Id: broyden.c 2139 2013-03-03 22:13:06Z beerli $
+ $Id: broyden.c 2169 2013-08-24 19:02:04Z beerli $
 started 1996
 -------------------------------------------------------*/
 /*! \file broyden.c
@@ -578,7 +578,7 @@ calc_locus_like (nr_fmt * nr, MYREAL *param, MYREAL *lparam, long locus)
     const MYREAL inheritance = 1./ inv_inheritance;
     const MYREAL tlmu_rate = lmu_rate + log(inheritance);
     const MYREAL tmu_rate = mu_rate * inheritance;
-    const MYREAL tinv_mu_rate = inv_mu_rate * inheritance;
+    //const MYREAL tinv_mu_rate = inv_mu_rate * inheritance;
     MYREAL normaldev;
 #ifdef LONGSUM
 
