@@ -220,7 +220,7 @@ $Id: definitions.h 2177 2013-12-16 18:39:54Z beerli $
     #define MYSNPRINTF _snprintf
 #else  
     #define MYISNAN  isnan
-    #define MYFINITE finite
+    #define MYFINITE isfinite
     #define MYSNPRINTF snprintf
     #ifdef __MWERKS__
 		#define MYINLINE /*inline*/
