@@ -215,7 +215,7 @@ void print_mutationrate_weights(FILE *file, MYREAL *murates, long *segregs, MYRE
 {
   long locus;
   //  char ***buffer;
-  long rows = loci+2;
+  //long rows = loci+2;
   float mumean=0.0;
   float segregmean=0.0;
   float wamean=0.0;
